Enum Handle
pub enum Handle {
Path(Id, PathBuf),
Bytes(Id, Bytes),
Rgba {
id: Id,
width: u32,
height: u32,
pixels: Bytes,
},
}Expand description
A handle of some image data.
Variants
Path(Id, PathBuf)
A file handle. The image data will be read from the file path.
Use from_path to create this variant.
Bytes(Id, Bytes)
A handle pointing to some encoded image bytes in-memory.
Use from_bytes to create this variant.
Rgba
A handle pointing to decoded image pixels in RGBA format.
Use from_rgba to create this variant.
Implementations
impl Handle
impl Handle
pub fn from_path<T>(path: T) -> Handle
Available on crate feature image only.
pub fn from_path<T>(path: T) -> Handle
image only.Creates an image Handle pointing to the image of the given path.
Makes an educated guess about the image format by examining the data in the file.
pub fn from_bytes(bytes: impl Into<Bytes>) -> Handle
Available on crate feature image only.
pub fn from_bytes(bytes: impl Into<Bytes>) -> Handle
image only.Creates an image Handle containing the encoded image data directly.
Makes an educated guess about the image format by examining the given data.
This is useful if you already have your image loaded in-memory, maybe because you downloaded or generated it procedurally.